@@ -164,12 +164,12 @@ impl_Bonobo_PropertyBag_getValue (PortableServer_Servant  servant,
 	}
 
 	bonobo_closure_invoke (prop->priv->get_prop,
-			       BONOBO_TYPE_CORBA_ANY,       &arg,
-			       BONOBO_TYPE_PROPERTY_BAG,    pb,
-			       BONOBO_TYPE_CORBA_TYPECODE,  prop->type,
-			       G_TYPE_UINT,                 prop->idx,
-			       BONOBO_TYPE_CORBA_EXCEPTION, ev,
-			       0);
+			       BONOBO_TYPE_STATIC_CORBA_ANY,       &arg,
+			       BONOBO_TYPE_PROPERTY_BAG,           pb,
+			       BONOBO_TYPE_STATIC_CORBA_TYPECODE,  prop->type,
+			       G_TYPE_UINT,                        prop->idx,
+			       BONOBO_TYPE_STATIC_CORBA_EXCEPTION, ev,
+			       G_TYPE_INVALID);
 
 	return arg;
 }
@@ -205,12 +205,12 @@ impl_Bonobo_PropertyBag_getValues (PortableServer_Servant  servant,
 			CORBA_string_dup (prop->name);
 
 		bonobo_closure_invoke (prop->priv->get_prop,
-				       BONOBO_TYPE_CORBA_ANY,       &arg,
-				       BONOBO_TYPE_PROPERTY_BAG,    pb,
-				       BONOBO_TYPE_CORBA_TYPECODE,  prop->type,
-				       G_TYPE_UINT,                 prop->idx,
-				       BONOBO_TYPE_CORBA_EXCEPTION, ev,
-				       0);
+				       BONOBO_TYPE_STATIC_CORBA_ANY,       &arg,
+				       BONOBO_TYPE_PROPERTY_BAG,           pb,
+				       BONOBO_TYPE_STATIC_CORBA_TYPECODE,  prop->type,
+				       G_TYPE_UINT,                        prop->idx,
+				       BONOBO_TYPE_STATIC_CORBA_EXCEPTION, ev,
+				       G_TYPE_INVALID);
 
 		set->_buffer [set->_length].value = *arg;
 
@@ -245,11 +245,11 @@ impl_Bonobo_PropertyBag_setValue (PortableServer_Servant  servant,
 
 	bonobo_closure_invoke (prop->priv->set_prop,
 			       G_TYPE_NONE,
-			       BONOBO_TYPE_PROPERTY_BAG,    pb,
-			       BONOBO_TYPE_CORBA_ANY,       value,
-			       G_TYPE_UINT,                 prop->idx,
-			       BONOBO_TYPE_CORBA_EXCEPTION, ev,
-			       0);
+			       BONOBO_TYPE_PROPERTY_BAG,           pb,
+			       BONOBO_TYPE_STATIC_CORBA_ANY,       value,
+			       G_TYPE_UINT,                        prop->idx,
+			       BONOBO_TYPE_STATIC_CORBA_EXCEPTION, ev,
+			       G_TYPE_INVALID);
 
 	if (prop->flags & Bonobo_PROPERTY_NO_AUTONOTIFY)
 		return;
@@ -292,11 +292,11 @@ impl_Bonobo_PropertyBag_setValues (PortableServer_Servant    servant,
 		
 		bonobo_closure_invoke (prop->priv->set_prop,
 				       G_TYPE_NONE,
-				       BONOBO_TYPE_PROPERTY_BAG,    pb,
-				       BONOBO_TYPE_CORBA_ANY,       &set->_buffer [i].value,
-				       G_TYPE_UINT,                 prop->idx,
-				       BONOBO_TYPE_CORBA_EXCEPTION, ev,
-				       0);
+				       BONOBO_TYPE_PROPERTY_BAG,           pb,
+				       BONOBO_TYPE_STATIC_CORBA_ANY,       &set->_buffer [i].value,
+				       G_TYPE_UINT,                        prop->idx,
+				       BONOBO_TYPE_STATIC_CORBA_EXCEPTION, ev,
+				       G_TYPE_INVALID);
 
 		if (BONOBO_EX (ev))
 			return;
@@ -781,7 +781,6 @@ bonobo_property_bag_map_params (BonoboPropertyBag *pb,
 		GType                value_type;
 		Bonobo_PropertyFlags flags;
 		BonoboArgType        type;
-		char                *desc;
 
 		pspec = pspecs [i];
 		value_type = G_PARAM_SPEC_VALUE_TYPE (pspec);
@@ -797,18 +796,15 @@ bonobo_property_bag_map_params (BonoboPropertyBag *pb,
 
 		flags = flags_gparam_to_bonobo (pspec->flags);
 
-		desc = g_strconcat (pspec->name, " is a ",
-				    g_type_name (value_type), NULL);
-
-#ifdef MAPPING_DEBUG
-		g_warning ("Mapping '%s'", desc);
-#endif
 		bonobo_property_bag_add_full
-			(pb, pspec->name, i, type,
-			 NULL, desc, NULL, flags,
+			(pb, 
+			 g_param_spec_get_name ((GParamSpec *)pspec), 
+			 i, type, NULL,
+			 g_param_spec_get_nick ((GParamSpec *)pspec),
+			 g_param_spec_get_blurb ((GParamSpec *)pspec), 
+			 flags,
 			 g_cclosure_new (G_CALLBACK (get_prop), (gpointer) pspec, NULL),
 			 g_cclosure_new (G_CALLBACK (set_prop), (gpointer) pspec, NULL));
-		g_free (desc);
 	}
 }
 
